#!/bin/sh

. /etc/utils/shell-utils.sh
DEBUG=1

WIFI_CURR_DRIVER_FILE=/ram/wifi/curr_driver
WIFI_HANDLE_LOCK_FILE=/ram/wifi.lock


wifi_driver=$(cat "$WIFI_CURR_DRIVER_FILE" 2>/dev/null)

log "wifi_driver=$wifi_driver"
if [ -n "$wifi_driver" ]; then
    log "[i] External WIFI dongle active. Aborting embedded WIFI start and initializing external WIFI"
    /etc/init.d/wifi_if_handler.sh start
    exit 0
fi

export LD_LIBRARY_PATH="/usr/local/lib:$LD_LIBRARY_PATH"

(
/bin/flock -x 555
log "[+] LOCK /ram/wifi.lock"


init_internal_8822cu()
{
    log "[+] Embedded RTL8822CU WIFI module FOUND."
    insmod /usr/lib/modules/rtl8822cu.ko
    echo "1" > /sys/module/rtl8822cu/parameters/rtw_drv_log_level
}

init_internal_8822bu()
{
    log "[+] Embedded RTL8822BU WIFI module FOUND."
    insmod /usr/lib/modules/rtl8822bu.ko
    echo "1" > /sys/module/rtl8822bu/parameters/rtw_drv_log_level
}

init_internal_8723du()
{
    log "[+] Embedded RTL8723DU WIFI module FOUND."
    gio="35"
    echo ${gio} > /sys/class/gpio/export
    echo out > /sys/class/gpio/gpio${gio}/direction
    echo 1 > /sys/class/gpio/gpio${gio}/value
    insmod /usr/lib/modules/rtl8723du.ko
    echo "4 4 1 7">/proc/sys/kernel/printk
}


case "$(lsusb)" in
  *0bda:c82c*)
        init_internal_8822cu
        ;;
  *0bda:b82c*)
        init_internal_8822bu
        ;;
  *0bda:d723*)
        init_internal_8723du
        ;;
  *)
esac


# init WIFI only if proper hardware module found
if [ -d /sys/class/net/wlan0/ ]; then
    ifconfig wlan0 up
    /usr/bin/wpa_supplicant -B -iwlan0 -Dnl80211 -c/etc/wpa_supplicant/wpa_supplicant.conf
    ipc_invoke "/etc/init.d/wifi_start_wa.sh &"
else
    log "[i] Embedded WIFI module not found. WIFI will be disabled until external module inserted"
fi

/bin/flock -u 555
log "[+] UNLOCK /ram/wifi.lock"
) 555>> $WIFI_HANDLE_LOCK_FILE
