#!/bin/sh

source /etc/utils/shell-utils.sh

upload_sboot=/ram/SbootIm
head_sboot=/ram/SbootHead
one_sboot=/ram/one_sboot.img
cmp_sboot=/ram/cmp_sboot.img

get_name_and_len_part "sbl2" max name_part

if [ "$1" != "" ]; then
    upload_sboot=$1
fi

if [ ! -e $upload_sboot ]; then
    echo "ERROR: File $upload_sboot not present!!!"
    exit 1
fi

get_file_size "$upload_sboot" size

if [ $size -eq 0 ]; then
    echo "ERROR: Uploading bootloader is failed."
    exit 1;
fi

get_flash_type type
if [ $type == "nand" ]; then

    rm -f $head_sboot
    dd if=$upload_sboot of=$head_sboot bs=1K count=1 2>/dev/null
    offset=`awk '{if($0 == "Start data..."){s+=length($0)+1;print s;exit;}else{s+=length($0)+1;}}' $head_sboot` 2>/dev/null
    dd if=/dev/null of=$head_sboot bs=1 count=0 seek=$offset 2>/dev/null

    get_model_ext model_ext
    get_hwver hwver
    if [ "$model_ext" == "MAG420" ]; then
        if [ "${hwver:4:3}" == "P0L" ]; then
            type="MAG420"
        fi
    fi
    if [ "$model_ext" == "IM4411WV" ]; then
        if [ "${hwver:4:3}" == "PWL" ]; then
            type="IM4411WV"
        fi
    fi

    get_name_and_len_part "bootloader" max vend_sect
    tmp=`grep -w "$type" $head_sboot` 2>/dev/null
    len=`echo "$tmp" | awk '{print $2}'`
    pos=`echo "$tmp" | awk '{print $3}'`
    echo "======[$type] [$len] [$pos] [$offset]======"
    if [ "$pos" != "" ] && [ "$len" != "" ]; then

        dd if=$upload_sboot of=$one_sboot skip=$(($pos+$offset)) bs=1 count=$len 2>/dev/null

        value1=`dd if=$one_sboot count=1 bs=$(($len-32)) | sha256sum | cut -d' ' -f1` 2>/dev/null
        value2=`hexdump -e '32/1 "%02x"' -s $(($len-32)) -n 32 $one_sboot`
        if [ "$value1" != "$value2" ]; then
            echo "ERROR: Hash sum mismatch!!!"
            exit 1
        fi

        value1=`hexdump -e '4/1 "%02x"' -s $(($len-36)) -n 4 $one_sboot`
        if [ "$value1" != "1e5b1fb1" ]; then
            echo "ERROR: Magic number mismatch!!!"
            exit 1
        fi

        value1=`hexdump -e '1/ "%d"' -s $(($max-256)) -n 4 /dev/$vend_sect`
        value2=`hexdump -e '1/ "%d"' -s $(($len-44)) -n 4 $one_sboot`
        if [ "$value1" -gt "$value2" ]; then
            rm -f $upload_sboot $head_sboot $one_sboot $cmp_sboot
            echo "OK"
            exit 0
        fi

        value1=`hexdump -e '1/ "%d"' -s $(($len-40)) -n 4 $one_sboot`
        if [ "$value1" -gt "0" ] && [ "$value1" -le "1024" ]; then
           len=$(($len-value1-40))
           dd if=/dev/null of=$one_sboot bs=1 count=0 seek=$len 2>/dev/null
        fi

        nanddump /dev/$name_part -l $len -f $cmp_sboot 2>/dev/null
        dd if=/dev/null of=$cmp_sboot bs=1 count=0 seek=$len 2>/dev/null

        cmp -s $cmp_sboot $one_sboot
        if [ ! "$?" -eq "0" ]; then
            echo "======Sboot is flashed with length [$len]======"
            flash_eraseall -q /dev/$name_part >/dev/null
            nandwrite -p /dev/$name_part $one_sboot >/dev/null
            if [ "$?" -ne "0" ]; then
                echo "ERROR: No matching bootloader found!!!"
                exit 1
            fi
        fi
    else
        echo "ERROR: Write to NAND flash failed!!!"
        exit 1
    fi
fi

rm -f $upload_sboot $head_sboot $one_sboot $cmp_sboot
echo "OK"
exit 0
